@@ -1,8 +1,8 @@
 use strict;
 use warnings;
 
-package App::Cmd::Command::version;
-$App::Cmd::Command::version::VERSION = '0.332';
+package App::Cmd::Command::version 0.335;
+
 use App::Cmd::Command;
 BEGIN { our @ISA = 'App::Cmd::Command'; }
 
@@ -47,20 +47,30 @@ App::Cmd::Command::version - display an app's version
 
 =head1 VERSION
 
-version 0.332
+version 0.335
 
 =head1 DESCRIPTION
 
 This command will display the program name, its base class
 with version number, and the full program name.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
