@@ -1,8 +1,8 @@
 use strict;
 use warnings;
 
-package App::Cmd::Simple;
-$App::Cmd::Simple::VERSION = '0.332';
+package App::Cmd::Simple 0.335;
+
 use App::Cmd::Command;
 BEGIN { our @ISA = 'App::Cmd::Command' }
 
@@ -74,7 +74,7 @@ use Sub::Install;
 #pod should be given in the format used for the C<$usage_desc> parameter to
 #pod C<describe_options> in Getopt::Long::Descriptive.
 #pod
-#pod If not overriden, it returns something that prints out like:
+#pod If not overridden, it returns something that prints out like:
 #pod
 #pod   yourapp [-?h] [long options...]
 #pod
@@ -224,7 +224,7 @@ App::Cmd::Simple - a helper for building one-command App::Cmd applications
 
 =head1 VERSION
 
-version 0.332
+version 0.335
 
 =head1 SYNOPSIS
 
@@ -268,6 +268,16 @@ and, finally, at the command line:
 
   All blorts successful.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 SUBCLASSING
 
 When writing a subclass of App::Cmd:Simple, there are only a few methods that
@@ -289,7 +299,7 @@ It's a one-line summary of how the command is to be invoked, and
 should be given in the format used for the C<$usage_desc> parameter to
 C<describe_options> in Getopt::Long::Descriptive.
 
-If not overriden, it returns something that prints out like:
+If not overridden, it returns something that prints out like:
 
   yourapp [-?h] [long options...]
 
@@ -331,11 +341,11 @@ That's how things work.  You can just do this:
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
