@@ -3,7 +3,7 @@ package Test::MyCmd;
 use strict;
 use warnings;
 
-use base qw(App::Cmd);
+use parent qw(App::Cmd);
 
 our $VERSION = '0.123';
 
