@@ -1,11 +1,11 @@
 package Test::MySimple;
 use strict;
 use warnings;
-use base 'App::Cmd::Simple';
+use parent 'App::Cmd::Simple';
 
 use Data::Dumper;
 
-sub run {
+sub execute {
   my ($self, $opt, $args) = @_;
 
   local $Data::Dumper::Terse = 1;
@@ -14,7 +14,7 @@ sub run {
 
 sub validate_args {
   my ($self, $opt, $args) = @_;
-  $self->usage_error("not enough args") unless @$args > 1;
+  $self->usage_error("not enough args") unless @$args > 0;
 }
 
 sub opt_spec {
