@@ -4,7 +4,7 @@ use warnings;
 # WSOF: with Setup, one file
 package Test::WSOF;
 use App::Cmd::Setup -app => {
-  plugins => [ qw(Test::XyzzyPlugin) ],
+  plugins => [ qw(=Test::XyzzyPlugin) ],
 };
 
 package Test::WSOF::Command::poot;
