@@ -3,7 +3,7 @@ use warnings;
 package Test::WithSetup::Command::alfie;
 use Test::WithSetup -command;
 
-sub run {
+sub execute {
   my ($self, $opt, $args) = @_;
   return $opt;
 }
